@@ -88,8 +88,23 @@ class LLMAnalyzer:
                                                  contributor_data, impact_data)
             print("\n=== Prompt Prepared ===")
             
+            # LOG THE ENTIRE INPUT BEING PASSED TO LLM
+            print("\n" + "="*80)
+            print("ENTIRE INPUT BEING PASSED TO LLM:")
+            print("="*80)
+            print("SYSTEM PROMPT:")
+            print(self.prompts["system_prompt"])
+            print("\n" + "="*80)
+            print("USER PROMPT (FULL DATA):")
+            print("="*80)
+            print(prompt)
+            print("="*80)
+            print("END OF LLM INPUT")
+            print("="*80 + "\n")
+            
             # Get analysis from OpenAI
             print("\n=== Calling OpenAI API ===")
+            print(f"FULL LLM INPUT OBJECT: {json.dumps({'system': self.prompts['system_prompt'], 'user': prompt}, indent=2)}")
             response = self.client.chat.completions.create(
                 model=self.model,
                 messages=[
@@ -158,6 +173,10 @@ Commit Activity:
 - Most Active Period: {commit_stats['most_active_period']}
 - Key Contributors: {', '.join(commit_stats['top_contributors'][:3])}
 - Major Changes: {commit_stats['major_changes']}
+- Major Code Changes: {len(commit_stats['major_code_changes'])}
+
+Major Code Changes (Top 10 Commits by Insertions):
+{self._format_major_code_changes(commit_stats['major_code_changes'])}
 
 Deep Code Analysis:
 {commit_analysis}
@@ -185,6 +204,7 @@ Important Requirements:
 - Include specific code patterns, algorithms, or systems involved
 - Explain the impact of each challenge on the project
 - Write in a clear, professional style with proper paragraphs
+- Pay special attention to the top commits by insertions as they often indicate significant technical challenges or solutions
 """
         return metrics
 
@@ -196,7 +216,8 @@ Important Requirements:
                 'last_commit': 'N/A',
                 'most_active_period': 'N/A',
                 'top_contributors': [],
-                'major_changes': 'N/A'
+                'major_changes': 'N/A',
+                'major_code_changes': []
             }
             
         # Get commit dates
@@ -218,14 +239,54 @@ Important Requirements:
                         if commit['insertions'] + commit['deletions'] > 1000]
         major_changes = f"Found {len(major_changes)} major changes"
         
+        # Identify major code changes based on insertions (more robust for technical challenges)
+        major_code_changes = []
+        
+        # Get top 10 commits by insertions
+        if commits:
+            # Sort commits by insertions and take top 10
+            top_commits_by_insertions = sorted(commits, key=lambda x: x['insertions'], reverse=True)[:10]
+            
+            for commit in top_commits_by_insertions:
+                major_code_changes.append({
+                    'hash': commit['hash'][:8],
+                    'date': commit['date'],
+                    'author': commit['author'],
+                    'message': commit['message'][:100] + '...' if len(commit['message']) > 100 else commit['message'],
+                    'insertions': commit['insertions'],
+                    'deletions': commit['deletions'],
+                    'files_changed': len(commit['files_changed'])
+                })
+        
+        # Sort by insertions (highest first)
+        major_code_changes.sort(key=lambda x: x['insertions'], reverse=True)
+        
         return {
             'first_commit': first_commit,
             'last_commit': last_commit,
             'most_active_period': f"{first_commit} to {last_commit}",
             'top_contributors': top_contributors,
-            'major_changes': major_changes
+            'major_changes': major_changes,
+            'major_code_changes': major_code_changes
         }
 
+    def _format_major_code_changes(self, major_code_changes: List[Dict[str, Any]]) -> str:
+        """Formats major code changes for prompt."""
+        if not major_code_changes:
+            return "No major code changes found."
+
+        formatted_changes = []
+        for change in major_code_changes:
+            formatted_changes.append(
+                f"Commit: {change['hash'][:8]} ({change['date']})"
+                f" - Author: {change['author']}"
+                f" - Message: {change['message']}"
+                f" - Insertions: {change['insertions']}"
+                f" - Deletions: {change['deletions']}"
+                f" - Files Changed: {change['files_changed']}"
+            )
+        return "\n".join(formatted_changes)
+
     def _analyze_commits_deep(self, commits: List[Dict[str, Any]]) -> str:
         """Perform deep analysis of commits using the code analyzer."""
         if not commits:
